/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Angular Notch Filter\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"prop"
    "erties\":{\"amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"d"
    "escription\":\"Mean amplitude [dB]\"},\"angle\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"},\"description\":\"Angle [deg]\"},\"range_mean\":{\"type\":\"arra"
    "y\",\"items\":{\"type\":\"number\"},\"description\":\"Mean range "
    "[m]\"}},\"description\":\"Angular notch filter parameters for window glass"
    " echoes\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209"
    "13,2.680913,2.610913,2.530913,2.570913,2.570913],\"angle\":[14.0,15.0,16"
    ".0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"range_mean\":[0.094,0.094,"
    "0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Atmospheric Parameters\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"p"
    "ressure_sl\",\"amsl\",\"group_velocity\",\"attenuation\",\"wavelength\"],\"prope"
    "rties\":{\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) [m]\"}},\"description\":\"Atmospheric "
    "parameters\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"rel_humidity\":63,\"pressure_sl\":970,\"pressure\":970,\"wavelength\":1550,"
    "\"temperature\":7,\"attenuation\":0.028125,\"group_velocity\":299711000.0,\"a"
    "msl\":0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Beam Geometry\",\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"required\":[\"beam_exit_diameter\",\"beam_divergence\"],\"properties"
    "\":{\"beam_exit_diameter\":{\"exclusiveMinimum\":false,\"type\":\"number\",\"min"
    "imum\":0,\"description\":\"Beam width at exit aperture [m]\"},\"beam_diverge"
    "nce\":{\"exclusiveMinimum\":false,\"type\":\"number\",\"minimum\":0,\"descriptio"
    "n\":\"Beam divergence in far field [rad]\"}},\"description\":\"Laser beam "
    "geometry details\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Control Object Catalog\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"types\"],\"properties\":{\"types\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangl"
    "e\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/ch"
    "evron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/"
    "cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/roun"
    "d_corner_cube_prism\"}]},\"uniqueItems\":true}},\"type\":\"object\",\"definiti"
    "ons\":{\"round_corner_cube_prism\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/d"
    "efinitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"r"
    "ound_corner_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"exclusiveMin"
    "imum\":true,\"type\":\"number\",\"minimum\":0,\"description\":\"diameter in mete"
    "rs\"}},\"type\":\"object\",\"required\":[\"shape\",\"diameter\"],\"description\":\"r"
    "ound corner cube prism specific properties\"}],\"description\":\"round "
    "corner cube prism\"},\"common\":{\"properties\":{\"shape\":{\"type\":\"string\",\""
    "enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\"circular_disk\",\"cylind"
    "er\",\"sphere\",\"round_corner_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"description\":{\"type\":\"string\",\"description\":\"string "
    "describing the object\"},\"surface_type\":{\"type\":\"string\",\"enum\":[\"retro"
    "_reflective_foil\",\"diffuse\"],\"description\":\"surface material "
    "type\"},\"name\":{\"minLength\":3,\"type\":\"string\",\"description\":\"unique "
    "type identifier\"}},\"type\":\"object\",\"required\":[\"name\",\"shape\"],\"descri"
    "ption\":\"common object properties\"},\"chevron\":{\"type\":\"object\",\"allOf\":"
    "[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"shape\":{\"type\":\"strin"
    "g\",\"enum\":[\"chevron\"],\"description\":\"shape identifier\"},\"thickness\":{\""
    "exclusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"description\":\"thic"
    "kness in meters\"},\"outside_edge_length\":{\"exclusiveMinimum\":true,\"type"
    "\":\"number\",\"minimum\":0,\"description\":\"length of the two outer edges in"
    " meters\"}},\"type\":\"object\",\"required\":[\"shape\",\"outside_edge_length\",\""
    "thickness\"],\"description\":\"chevron specific properties\"}],\"description"
    "\":\"chevron\"},\"checkerboard2x2\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/de"
    "finitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"ch"
    "eckerboard2x2\"],\"description\":\"shape identifier\"},\"square_length\":{\"ex"
    "clusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"description\":\"length"
    " of a square of the checkerboard in meters\"}},\"type\":\"object\",\"require"
    "d\":[\"shape\",\"square_length\"],\"description\":\"checkerboard specific "
    "properties\"}],\"description\":\"checkerboard 2 by 2\"},\"rectangle\":{\"type\""
    ":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"wid"
    "th\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"description\""
    ":\"width in meters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]},\"le"
    "ngth\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"descriptio"
    "n\":\"length in meters\"}},\"type\":\"object\",\"required\":[\"shape\",\"length\",\""
    "width\"],\"description\":\"rectangle specific properties\"}],\"description\":"
    "\"rectangle\"},\"circular_disk\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/defi"
    "nitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"circ"
    "ular_disk\"],\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"exclusiveMin"
    "imum\":true,\"type\":\"number\",\"minimum\":0,\"description\":\"diameter in mete"
    "rs\"}},\"type\":\"object\",\"required\":[\"shape\",\"diameter\"],\"description\":\"c"
    "ircular disk specific properties\"}],\"description\":\"circular disk\"},\"sp"
    "here\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"prop"
    "erties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"sphere\"],\"description\":\"sha"
    "pe identifier\"},\"diameter\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"m"
    "inimum\":0,\"description\":\"diameter in meters\"}},\"type\":\"object\",\"requir"
    "ed\":[\"shape\",\"diameter\"],\"description\":\"sphere specific properties\"}],"
    "\"description\":\"sphere\"},\"cylinder\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\""
    "#/definitions/common\"},{\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":"
    "[\"cylinder\"],\"description\":\"shape identifier\"},\"height\":{\"exclusiveMin"
    "imum\":true,\"type\":\"number\",\"minimum\":0,\"description\":\"height in meters"
    "\"},\"diameter\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"de"
    "scription\":\"diameter in meters\"}},\"type\":\"object\",\"required\":[\"shape\","
    "\"diameter\",\"height\"],\"description\":\"cylinder specific "
    "properties\"}],\"description\":\"cylinder\"}},\"description\":\"List of "
    "control object type definitions\"}"
    ,
    /* example: */
    "{\"types\":[{\"width\":0.3,\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(60cm x 30cm)\",\"length\":0.6,\"name\":\"Rectangle "
    "60x30\"},{\"width\":0.4,\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(80cm x 40cm)\",\"length\":0.8,\"name\":\"Rectangle "
    "80x40\"},{\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square"
    " length: 30cm)\",\"square_length\":0.3,\"name\":\"Checkerboard2x2 "
    "30\"},{\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 50cm)\",\"square_length\":0.5,\"name\":\"Checkerboard2x2 "
    "50\"},{\"shape\":\"chevron\",\"description\":\"Chevron (a=24''; b=4'')\",\"thick"
    "ness\":0.1016,\"outside_edge_length\":0.6096,\"name\":\"Chevron "
    "24''/4''\"},{\"diameter\":0.5,\"shape\":\"circular_disk\",\"description\":\" "
    "Circular Disk (diameter: "
    "50cm)\",\"surface_type\":\"diffuse\",\"name\":\"Circular Disk "
    "50\"},{\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"shape\":\"circular_disk\",\"offset\":0.0,\"diameter\""
    ":0.05},{\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 100 mm\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"shape\":\"circular_disk\",\"offset\":0.0,\"diameter\""
    ":0.1},{\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 150 mm\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"shape\":\"circular_disk\",\"offset\":0.0,\"diameter\""
    ":0.15},{\"surface_type\":\"retro_reflective_foil\",\"height\":0.05,\"descript"
    "ion\":\"cylindrical reflector from retro-reflective "
    "foil\",\"shape\":\"cylinder\",\"name\":\"RIEGL cylindrical reflector 50 mm\",\"d"
    "iameter\":0.05},{\"surface_type\":\"retro_reflective_foil\",\"height\":0.1,\"d"
    "escription\":\"cylindrical reflector from retro-reflective "
    "foil\",\"shape\":\"cylinder\",\"name\":\"RIEGL cylindrical reflector 100 mm\",\""
    "diameter\":0.1},{\"diameter\":0.2,\"shape\":\"sphere\",\"description\":\"Sphere "
    "(diameter: 200 mm)\",\"name\":\"Sphere 200 mm\"},{\"diameter\":0.05,\"shape\":\""
    "round_corner_cube_prism\",\"description\":\"round corner cube "
    "prism\",\"offset\":0.0,\"name\":\"Corner Cube Prism 50 "
    "mm\"}],\"comments\":[\"This file contains a list of control object types "
    "(aka. 'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Control Object Reference file\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"properties\":{\"reference_file\":{\"properties\":{\""
    "file_path\":{\"type\":\"string\",\"description\":\"Path of the control object "
    "file relative to referring "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"re"
    "quired\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference to a "
    "control object file\"}},\"type\":\"object\",\"description\":\"Details about "
    "the control object reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Detection Probability\",\"$schema\":\"http://json-schema.org/dra"
    "ft-04/schema#\",\"required\":[\"amplitude\",\"detection_probability\"],\"prope"
    "rties\":{\"amplitude\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"Amplitude [dB]\"},\"detection_probability\":{\"type\":\"array\",\"items"
    "\":{\"type\":\"number\"},\"description\":\"Detection probability "
    "[0..1]\"}},\"description\":\"Detection probability as a function of "
    "amplitude\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Information\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"required\":[\"device_type\",\"serial_number\"],\"properties\":{\""
    "channel_number\":{\"exclusiveMinimum\":false,\"type\":\"integer\",\"minimum\":0"
    ",\"description\":\"Laser channel number (not defined or 0: single channel"
    " device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. S2221234)\"}},\"description\":\"Details about the "
    "device used to acquire the point cloud\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"channel_number\":0,\"channel_text\":\"\",\"device_type\":\"VZ-400i\",\"device_"
    "build\":\"\",\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Geometry\",\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"required\":[\"primary\"],\"properties\":{\"amu\":{\"properties\":{\"fr"
    "ameCC\":{\"exclusiveMinimum\":false,\"type\":\"number\",\"minimum\":0,\"descript"
    "ion\":\"Frame Circle Count (number of LSBs per full rotation about frame"
    " axis)\"},\"lineCC\":{\"exclusiveMinimum\":false,\"type\":\"number\",\"minimum\":"
    "0,\"description\":\"Line Circle Count (number of LSBs per full rotation "
    "about line axis)\"}},\"type\":\"object\",\"description\":\"Angle Measurement U"
    "nit\"},\"secondary\":{\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"},\"description\":\"Internal calibration values\"},\"ID\":{\"min"
    "Items\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"maxItems\":2,\"descr"
    "iption\":\"Structure identifier\"}},\"type\":\"object\",\"required\":[\"ID\",\"con"
    "tent\"],\"description\":\"Additional device geometry structure (optional)\""
    "},\"primary\":{\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\""
    "number\"},\"description\":\"Internal calibration values\"},\"ID\":{\"minItems\""
    ":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"maxItems\":2,\"description"
    "\":\"Structure identifier\"}},\"type\":\"object\",\"required\":[\"ID\",\"content\"]"
    ",\"description\":\"Primary device geometry structure "
    "(mandatory)\"}},\"description\":\"Scanner device geometry "
    "details\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amu\":{\"frameCC\":124000,\"lineCC\":124000},\"secondary\":{\"content\":[0],\""
    "ID\":[91,0]},\"primary\":{\"content\":[0],\"ID\":[4,0]}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Geometry Passive Channel\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"required\":[\"primary\"],\"properties\":{\"primary"
    "\":{\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\""
    "description\":\"Internal calibration values\"},\"ID\":{\"minItems\":2,\"type\":"
    "\"array\",\"items\":{\"type\":\"integer\"},\"maxItems\":2,\"description\":\"Structu"
    "re identifier\"}},\"type\":\"object\",\"required\":[\"ID\",\"content\"],\"descript"
    "ion\":\"Primary device geometry structure "
    "(mandatory)\"}},\"description\":\"Scanner passive channel device geometry "
    "details\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Output Limits\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"properties\":{\"mta_zone_count_maximum\":{\"type\":\"number\","
    "\"description\":\"Maximum number of MTA "
    "zones.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"reflectance_minimum\":{\"type\":\"numbe"
    "r\",\"description\":\"Minimum possible reflectance in "
    "dB.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible"
    " range in meters.\"},\"background_radiation_minimum\":{\"type\":\"number\",\"d"
    "escription\":\"Minimum possible background radiation.\"},\"amplitude_minim"
    "um\":{\"type\":\"number\",\"description\":\"Minimum possible amplitude in "
    "dB.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape "
    "deviation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in dB.\"},\"background_radiation_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum possible background radiation.\"},\"reflect"
    "ance_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible "
    "reflectance in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\"}},\"type\":\"object\",\"description\":\"Limits of the measured values "
    "output by the device. The limits depend on the device type, "
    "measurement program and/or scan pattern.\"}"
    ,
    /* example: */
    "{\"amplitude_minimum\":0.0,\"deviation_maximum\":32767,\"background_radiati"
    "on_maximum\":0,\"mta_zone_count_maximum\":7,\"reflectance_maximum\":100.0,\""
    "reflectance_minimum\":-100.0,\"range_minimum\":2.9,\"background_radiation_"
    "minimum\":0,\"amplitude_maximum\":100.0,\"range_maximum\":10000.0,\"deviatio"
    "n_minimum\":-1}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Devices Information\",\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"items\":{\"properties\":{\"signed\":{\"type\":\"boolean\",\"descri"
    "ption\":\"Flag that is set when the original 'riegl.device' entry in the"
    " source file was correctly signed.\"},\"channel_number\":{\"exclusiveMinim"
    "um\":false,\"type\":\"integer\",\"minimum\":0,\"description\":\"Laser channel "
    "number (not defined or 0: single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. S2221234)\"}},\"type\":\"object\",\"required\":[\"device_t"
    "ype\",\"serial_number\"]},\"type\":\"array\",\"description\":\"Details about the"
    " devices used to acquire the point cloud (e.g. when merging point "
    "clouds of different devices)\"}"
    ,
    /* example: */
    "[{\"signed\":false,\"channel_number\":0,\"channel_text\":\"\",\"device_type\":\"V"
    "Z-400i\",\"device_build\":\"\",\"device_name\":\"Scanner 1\",\"serial_number\":\"S"
    "2221234\"},{\"signed\":true,\"channel_number\":1,\"channel_text\":\"\",\"device_"
    "type\":\"VQ-1560i-DW\",\"device_build\":\"\",\"device_name\":\"Scanner 2\",\"seria"
    "l_number\":\"S2222680\"},{\"signed\":true,\"channel_number\":2,\"channel_text\""
    ":\"\",\"device_type\":\"VQ-1560i-DW\",\"device_build\":\"\",\"device_name\":\"Scann"
    "er 3\",\"serial_number\":\"S2222680\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Dyntrig\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"properties\":{\"scale\":{\"type\":\"number\",\"description\":\"Scale in units "
    "of dB, for calculation of line: line number N=(amplitude-offset)/scale"
    "\"},\"tab\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"properties\":{\"thra2\":{"
    "\"type\":\"number\",\"description\":\"Pre-trigger threshold in units of "
    "dB\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of m\"}},\"type\":\"object\",\"requ"
    "ired\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\"..."
    "\"},\"description\":\"...\",\"maxItems\":128},\"post\":{\"properties\":{\"nc\":{\"ty"
    "pe\":\"integer\",\"description\":\"Number of entries\",\"minimum\":0,\"maximum\":"
    "255},\"a\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"...\",\"maxItems\":2080}},\"type\":\"object\",\"required\":[\"nc\",\"a\"],"
    "\"description\":\"Dyntrig post values\"},\"pre\":{\"properties\":{\"nc\":{\"type\""
    ":\"integer\",\"description\":\"Number of entries\",\"minimum\":0,\"maximum\":255"
    "},\"a\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descript"
    "ion\":\"...\",\"maxItems\":2080}},\"type\":\"object\",\"required\":[\"nc\",\"a\"],\"de"
    "scription\":\"Dyntrig pre "
    "values\"},\"offset\":{\"type\":\"number\",\"description\":\"Offset in units of "
    "dB, for calculation of line\"}},\"description\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"scale\":1.0,\"tab\":[{\"thra2\":0.0,\"del1\":0.0,\"dec1\":0.0,\"thra1\":0.0,\"de"
    "c2\":0.0,\"del2\":0.0}],\"post\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"pre\":{\""
    "nc\":128,\"a\":[78,86,126,134,31]},\"offset\":0.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Echo Information\",\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"required\":[\"echo_file\"],\"properties\":{\"echo_file\":{\"propert"
    "ies\":{\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\":[\"file_exte"
    "nsion\"]}},\"description\":\"Details about echo files\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_extension\":\"owp\",\"file_uuid\":\"26a03615-67c0-4bea-8"
    "fe8-c577378fe661\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Exponential Decomposition\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"type\":\"object\",\"definitions\":{\"channel\":{\"properti"
    "es\":{\"scale\":{\"type\":\"number\",\"description\":\"amplitude "
    "calibration\"},\"delay\":{\"type\":\"number\",\"description\":\"delay "
    "calibration in seconds\"},\"parameter\":{\"properties\":{\"gamma\":{\"type\":\"a"
    "rray\",\"items\":{\"type\":\"number\"},\"description\":\"decay in 1/second\"},\"B\""
    ":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"imaginary "
    "part of amplitude factor in units of full-scale\"},\"A\":{\"type\":\"array\","
    "\"items\":{\"type\":\"number\"},\"description\":\"real part of amplitude factor"
    " in units of full-scale\"},\"omega\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"},\"description\":\"angular frequency in Hz\"}},\"type\":\"object\",\"requi"
    "red\":[\"A\",\"B\",\"gamma\",\"omega\"],\"description\":\"parameters of the "
    "syswave exponential sum\"},\"a_lin\":{\"exclusiveMaximum\":false,\"minimum\":"
    "0,\"maximum\":1,\"exclusiveMinimum\":false,\"type\":\"number\",\"description\":\""
    "relative linear amplitude range [0..1]\"}},\"type\":\"object\",\"required\":["
    "\"delay\",\"scale\",\"parameter\"]}},\"description\":\"Details for exponential "
    "decomposition of full waveform data\",\"additionalProperties\":false,\"pat"
    "ternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/channel\",\"descripti"
    "on\":\"one field per channel, field name is channel index\"}}}"
    ,
    /* example: */
    "{\"1\":{\"scale\":1.0,\"delay\":3.5e-09,\"parameter\":{\"gamma\":[-1094726528.0,"
    "-769562752.0,-848000064.0],\"B\":[-3.9,0.0,-0.3],\"A\":[0.9,0.3,-1.3],\"ome"
    "ga\":[352020896.0,3647927552.0,-1977987072.0]},\"a_lin\":0.9},\"0\":{\"scale"
    "\":1.0,\"delay\":3.783458418887631e-09,\"parameter\":{\"gamma\":[-1094726528."
    "0,-769562752.0,-848000064.0],\"B\":[-3.9813032150268555,0.08622030913829"
    "803,-0.3152860999107361],\"A\":[0.9772450923919678,0.3354335129261017,-1"
    ".312678575515747],\"omega\":[352020896.0,3647927552.0,-1977987072.0]},\"a"
    "_lin\":0.27}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Gaussian Decomposition\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_h"
    "igh_power\",\"amplitude_db\",\"range_offset_sec_low_power\",\"range_offset_s"
    "ec_high_power\"],\"properties\":{\"amplitude_db\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"}},\"range_offset_sec_high_power\":{\"type\":\"array\",\"items"
    "\":{\"type\":\"number\"}},\"amplitude_lsb_low_power\":{\"type\":\"array\",\"items\""
    ":{\"type\":\"number\"}},\"range_offset_sec_low_power\":{\"type\":\"array\",\"item"
    "s\":{\"type\":\"number\"}},\"amplitude_lsb_high_power\":{\"type\":\"array\",\"item"
    "s\":{\"type\":\"number\"}}},\"description\":\"riegl.gaussian_decomposition "
    "contains information relevant for extracting calibrated amplitudes and"
    " calibrated ranges from a Gaussian decomposition of full waveform "
    "data. This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_db\":[],\"range_offset_sec_high_power\":[],\"amplitude_lsb_low"
    "_power\":[],\"range_offset_sec_low_power\":[],\"amplitude_lsb_high_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Geo Tag\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"properties\":{\"crs\":{\"properties\":{\"wkt\":{\"type\":\"string\",\"descriptio"
    "n\":\"\\\"Well-Known Text\\\" string, OGC WKT dialect (see http://www.openge"
    "ospatial.org/standards/wkt-crs)\"},\"epsg\":{\"type\":\"integer\",\"minimum\":0"
    ",\"description\":\"EPSG "
    "code\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate reference "
    "system name\"}},\"type\":\"object\",\"description\":\"Global Coordinate "
    "Reference System. Please note that only 3D Cartesian Coordinate "
    "Systems are allowed.\"},\"pose\":{\"minItems\":4,\"type\":\"array\",\"items\":{\"m"
    "inItems\":4,\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\":\"colu"
    "mns\"},\"maxItems\":4,\"description\":\"rows\"},\"maxItems\":4,\"description\":\"C"
    "oordinate Transformation Matrix to transform from File Coordinate "
    "System to Global Coordinate Reference System. 4x4 matrix stored as two"
    " dimensional array, row major "
    "order.\"}},\"type\":\"object\",\"description\":\"Point cloud georeferencing "
    "information\"}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"epsg\":4978,\"name\":\"WGS84 Geocentr"
    "ic\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"exclusiveMinimum\":true,\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"minimum\":0,\"type\":\"number\",\"description\":\"Geometric scale "
    "factor applied to point coordinates\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Georeferencing Parameters\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"properties\":{\"socs_to_rocs_matrix\":{\"minItems\":4,\""
    "type\":\"array\",\"items\":{\"minItems\":4,\"type\":\"array\",\"items\":{\"type\":\"nu"
    "mber\",\"description\":\"columns\"},\"maxItems\":4,\"description\":\"rows\"},\"max"
    "Items\":4,\"description\":\"Coordinate Transformation Matrix to transform "
    "from Scanner's Own Coordinate System to Record Coordinate System. 4x4 "
    "matrix stored as two dimensional array, row major order.\"},\"socs_to_bo"
    "dy_matrix\":{\"minItems\":4,\"type\":\"array\",\"items\":{\"minItems\":4,\"type\":\""
    "array\",\"items\":{\"type\":\"number\",\"description\":\"columns\"},\"maxItems\":4,"
    "\"description\":\"rows\"},\"maxItems\":4,\"description\":\"Coordinate "
    "Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\"},\"body_coordinate_system_type\":{\"type\":\"stri"
    "ng\",\"enum\":[\"NED\",\"ENU\"],\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: NED\"},\"trajectory_file\""
    ":{\"properties\":{\"file_extension\":{\"type\":\"string\",\"description\":\"Traje"
    "ctory file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\":[\"file_exte"
    "nsion\"],\"description\":\"Trajectory data used for georeferencing of the "
    "point cloud\"},\"trajectory_offsets\":{\"properties\":{\"offset_pitch\":{\"typ"
    "e\":\"number\",\"description\":\"[deg]\"},\"offset_north\":{\"type\":\"number\",\"de"
    "scription\":\"[m]\"},\"version\":{\"type\":\"integer\",\"description\":\"Meaning "
    "of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\""
    "},\"offset_height\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_east\":"
    "{\"type\":\"number\",\"description\":\"[m]\"},\"offset_roll\":{\"type\":\"number\",\""
    "description\":\"[deg]\"},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[de"
    "g]\"}},\"type\":\"object\",\"description\":\"Correction offsets applied to the"
    " trajectory data\"}},\"type\":\"object\",\"description\":\"Parameters used for"
    " georeferencing of the point cloud\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "body_coordinate_system_type\":\"NED\",\"trajectory_file\":{\"file_extension\""
    ":\"pofx\",\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\"},\"trajector"
    "y_offsets\":{\"offset_pitch\":0.01,\"offset_north\":0.07,\"version\":0,\"offse"
    "t_time\":18.007,\"offset_height\":-0.2,\"offset_east\":0.15,\"offset_roll\":0"
    ".03,\"offset_yaw\":-0.45}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Item Names\",\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\",\"description\":\"Map of item names\",\"type\":\"object\",\"additionalPrope"
    "rties\":false,\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"descr"
    "iption\":\"One field per item, field name is item id, field value is "
    "item name\"}}}"
    ,
    /* example: */
    "{\"1\":\"Name of item with id 1\",\"2\":\"Name of item with id 2\",\"47\":\"Name "
    "of item with id 47\",\"-1\":\"Name of item with id -1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Software License Keys\",\"$schema\":\"http://json-schema.org/dra"
    "ft-04/schema#\",\"description\":\"License keys for software features\",\"typ"
    "e\":\"object\",\"additionalProperties\":false,\"patternProperties\":{\"^.*$\":{"
    "\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"string\",\"description\":\"Li"
    "cense key (example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"description\":\"Each field of the object represents a "
    "feature and holds a list of license keys, where the field name is the "
    "feature name.\"}}}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography with GPU support\":[\"8AB44126 - "
    "23B92250 - 16E2689F - 34EF7E7B\"],\"Full Waveform Analysis "
    "Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - 8D2ED557\"],\"MTA "
    "resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"MTA Settings\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"properties\":{\"zone_width\":{\"type\":\"number\",\"minimum\":0,\"descrip"
    "tion\":\"Width of a MTA zone in meter.\"},\"modulation_depth\":{\"type\":\"num"
    "ber\",\"minimum\":0,\"description\":\"Depth of pulse position modulation in "
    "meter.\"},\"zone_count\":{\"type\":\"integer\",\"maximum\":255,\"minimum\":0,\"des"
    "cription\":\"Maximum number of MTA "
    "zones.\"}},\"type\":\"object\",\"description\":\"Parameters for MTA "
    "processing\"}"
    ,
    /* example: */
    "{\"zone_width\":149.896225,\"modulation_depth\":9.368514,\"zone_count\":23}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Near Range Correction Table\",\"$schema\":\"http://json-schema.o"
    "rg/draft-04/schema#\",\"required\":[\"delta\",\"content\"],\"properties\":{\"con"
    "tent\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems"
    "\":2000,\"description\":\"Correction value [m] to be added to the raw "
    "range\"},\"delta\":{\"type\":\"number\",\"description\":\"Delta between table "
    "entries [m], first entry is at range = 0 m\"}},\"description\":\"Lookup "
    "table for range correction based on raw range\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"content\":[0.0],\"delta\":0.512}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Noise Estimates\",\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"pro"
    "perties\":{\"amplitude_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},"
    "\"description\":\"Sigma amplitude [dB]\"},\"range_sigma\":{\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\"},\"description\":\"Sigma range [m]\"},\"amplitude\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Amplitude "
    "[dB]\"}},\"description\":\"Standard deviation for range and amplitude as a"
    " function of amplitude\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.02"
    "4,0.021,0.018,0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Notch Filter\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"]"
    ",\"properties\":{\"amplitude_maximum\":{\"type\":\"number\",\"minimum\":0,\"descr"
    "iption\":\"Maximum amplitude "
    "[dB]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range "
    "[m]\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"}},\"description\":\"Notch filter parameters for window glass "
    "echoes\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pixel Information\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"required\":[\"size\"],\"properties\":{\"size\":{\"$ref\":\"#/definit"
    "ions/pixel_size\",\"description\":\"Size of pixels in file coordinate syst"
    "em.\"},\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Si"
    "ze of pixels in a locally levelled cartesian coordinate system (xy). "
    "This is only used for pixels based on a map projection.\"}},\"type\":\"obj"
    "ect\",\"definitions\":{\"pixel_size\":{\"minItems\":2,\"type\":\"array\",\"items\":"
    "{\"type\":\"number\",\"minimum\":0,\"description\":\"Length of pixel edge "
    "[m].\"},\"maxItems\":2,\"description\":\"Size of "
    "pixels.\"}},\"description\":\"Details about the pixels contained in the "
    "file\"}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Plane Patch Matching\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two"
    "\"],\"properties\":{\"plane_patch_file_two\":{\"$ref\":\"#/definitions/file_re"
    "ference\",\"description\":\"Reference to the plane patch file two\"},\"plane"
    "_patch_file_one\":{\"$ref\":\"#/definitions/file_reference\",\"description\":"
    "\"Reference to the plane patch file one\"}},\"type\":\"object\",\"definitions"
    "\":{\"file_reference\":{\"properties\":{\"file_path\":{\"type\":\"string\",\"descr"
    "iption\":\"Path of the plane patch file relative to the match "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\""
    ":[\"file_uuid\",\"file_path\"],\"description\":\"Reference to a plane patch "
    "file\"}},\"description\":\"Details about the plane patch matching "
    "process\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Plane Patch Statistics\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"properties\":{\"total_horizontal_area\":{\"type\":\"number\""
    ",\"description\":\"sum of all plane patch areas projected to horizontal "
    "plane [m\\u00b2]\"},\"total_area\":{\"type\":\"number\",\"description\":\"sum of "
    "all plane patch areas "
    "[m\\u00b2]\"}},\"type\":\"object\",\"description\":\"Statistics about plane "
    "patches found by plane patch extractor\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Plane Slope Class Info\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"settings\",\"classes\"],\"properties\":{\"class"
    "es\":{\"type\":\"object\",\"additionalProperties\":false,\"patternProperties\":"
    "{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one field per class, field"
    " name is class number, field value is class "
    "name\"}},\"description\":\"Class definition table\"},\"settings\":{\"type\":\"ob"
    "ject\",\"oneOf\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definition"
    "s/method-2\"}],\"description\":\"Classification settings, details see "
    "documentation of rdbplanes\"}},\"type\":\"object\",\"definitions\":{\"method-1"
    "\":{\"properties\":{\"maximum_inclination_angle_horizontal\":{\"type\":\"numbe"
    "r\",\"maximum\":360.0,\"minimum\":-360.0,\"description\":\"maximum inclination"
    " angle of horizontal plane patches [deg]\"},\"plane_classification_metho"
    "d\":{\"type\":\"integer\",\"maximum\":1,\"minimum\":1,\"description\":\"method ID "
    "(=1)\"}},\"type\":\"object\",\"required\":[\"plane_classification_method\",\"max"
    "imum_inclination_angle_horizontal\"],\"description\":\"Classification "
    "method 1\"},\"method-2\":{\"properties\":{\"sloping_plane_classes_maximum_an"
    "gle\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360.0,\"description\":\""
    "maximum inclination angle of sloping plane patches [deg]\"},\"plane_clas"
    "sification_method\":{\"type\":\"integer\",\"maximum\":2,\"minimum\":2,\"descript"
    "ion\":\"method ID (=2)\"},\"sloping_plane_classes_minimum_angle\":{\"type\":\""
    "number\",\"maximum\":360.0,\"minimum\":-360.0,\"description\":\"minimum "
    "inclination angle of sloping plane patches [deg]\"}},\"type\":\"object\",\"r"
    "equired\":[\"plane_classification_method\",\"sloping_plane_classes_minimum"
    "_angle\",\"sloping_plane_classes_maximum_angle\"],\"description\":\"Classifi"
    "cation method 2\"}},\"description\":\"Settings and classes for plane slope"
    " classification\"}"
    ,
    /* example: */
    "{\"classes\":{\"14\":\"horizontal, pointing down\",\"6\":\"vertical, pointing "
    "east\",\"2\":\"sloping, pointing up and east\",\"10\":\"sloping, pointing down"
    " and east\",\"5\":\"sloping, pointing up and west\",\"7\":\"vertical, pointing"
    " south\",\"11\":\"sloping, pointing down and south\",\"13\":\"sloping, "
    "pointing down and west\",\"1\":\"horizontal, pointing up\",\"12\":\"sloping, "
    "pointing down and north\",\"8\":\"vertical, pointing north\",\"3\":\"sloping, "
    "pointing up and south\",\"9\":\"vertical, pointing west\",\"4\":\"sloping, "
    "pointing up and north\"},\"settings\":{\"sloping_plane_classes_maximum_ang"
    "le\":70.0,\"plane_classification_method\":2,\"sloping_plane_classes_minimu"
    "m_angle\":10.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Point Attribute Groups\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"description\":\"Grouping and sorting of point "
    "attributes for visualization purposes\",\"type\":\"object\",\"additionalProp"
    "erties\":false,\"patternProperties\":{\"^.*$\":{\"minItems\":1,\"type\":\"array\""
    ",\"items\":{\"type\":\"string\",\"description\":\"Point attribute full name or "
    "name pattern (perl regular expression syntax)\"},\"description\":\"Each "
    "field of the object represents a point attribute group and holds a "
    "list of point attributes, where the field name is the group name.\"}}}"
    ,
    /* example: */
    "{\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Primary"
    " Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]"
    ",\"Time\":[\"riegl.timestamp\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Point Cloud Information\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"properties\":{\"field_of_application\":{\"type\":\"string\""
    ",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"d"
    "escription\":\"Field of "
    "application\"},\"project\":{\"type\":\"string\",\"description\":\"Project name\"}"
    ",\"comments\":{\"type\":\"string\",\"description\":\"Comments\"}},\"type\":\"object"
    "\",\"description\":\"Details about point cloud files\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"project\":\"Campaign 4\",\"comments\":\"Line "
    "3\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pose Estimation\",\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"required\":[\"orientation\"],\"properties\":{\"position\":{\"propert"
    "ies\":{\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate 3 as "
    "defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"crs\":{\"p"
    "roperties\":{\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"},\"epsg\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"EPSG "
    "code\"}},\"type\":\"object\",\"required\":[\"epsg\"],\"description\":\"Global "
    "Coordinate Reference System\"},\"vertical_accuracy\":{\"exclusiveMinimum\":"
    "true,\"type\":\"number\",\"minimum\":0,\"description\":\"Vertical accuracy "
    "[m]\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate 2 as "
    "defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"horizon"
    "tal_accuracy\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"de"
    "scription\":\"Horizontal accuracy "
    "[m]\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate 1 as "
    "defined by axis 1 of the specified CRS (e.g., X, Latitude)\"}},\"type\":\""
    "object\",\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"hori"
    "zontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"description\":\"Position "
    "coordinates and position accuracy values as measured by GNSS in the "
    "specified Coordinate Reference System (CRS)\"},\"barometric_height_amsl\""
    ":{\"type\":\"number\",\"description\":\"Altitude determined based on the "
    "atmospheric pressure according to the standard atmosphere laws [m].\"},"
    "\"orientation\":{\"properties\":{\"roll_accuracy\":{\"exclusiveMinimum\":true,"
    "\"type\":\"number\",\"minimum\":0,\"description\":\"Roll angle accuracy [deg]\"}"
    ",\"yaw\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-360,\"description\":\"Ya"
    "w angle about scanner Z-axis [deg]\"},\"pitch_accuracy\":{\"exclusiveMinim"
    "um\":true,\"type\":\"number\",\"minimum\":0,\"description\":\"Pitch angle "
    "accuracy [deg]\"},\"pitch\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-360"
    ",\"description\":\"Pitch angle about scanner Y-axis [deg]\"},\"roll\":{\"type"
    "\":\"number\",\"maximum\":360,\"minimum\":-360,\"description\":\"Roll angle "
    "about scanner X-axis [deg]\"},\"yaw_accuracy\":{\"exclusiveMinimum\":true,\""
    "type\":\"number\",\"minimum\":0,\"description\":\"Yaw angle accuracy [deg]\"}},"
    "\"type\":\"object\",\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitc"
    "h_accuracy\",\"yaw_accuracy\"],\"description\":\"Orientation values and "
    "orientation accuracies, measured with IMU or inclination "
    "sensors.\"}},\"description\":\"Estimated position and orientation "
    "information as measured by GNSS, IMU or inclination "
    "sensors\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"position\":{\"coordinate_3\":362.7124938964844,\"crs\":{\"wkt\":\"GEOGCS[\\\"W"
    "GS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298"
    ".257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]]"
    ",PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]]"
    ",UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],"
    "AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\"
    "\"4979\\\"]]\",\"epsg\":4979},\"vertical_accuracy\":1.3314999341964722,\"coordi"
    "nate_2\":15.645033406,\"horizontal_accuracy\":0.810699999332428,\"coordina"
    "te_1\":48.655799473},\"barometric_height_amsl\":386.7457796227932,\"orient"
    "ation\":{\"roll_accuracy\":0.009433783936875745,\"yaw\":101.87293630292045,"
    "\"pitch_accuracy\":0.009433783936875745,\"pitch\":1.509153024827064,\"roll\""
    ":3.14743073066123,\"yaw_accuracy\":1.0094337839368757}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pose Sensors\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"]"
    ",\"properties\":{\"accelerometer\":{\"properties\":{\"relative_nonlinearity\":"
    "{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, d"
    "imensionless\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\""
    "Value to be subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":"
    "\"#/definitions/vector\",\"description\":\"Sensitive X axis of sensor at "
    "frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"exclusiveMinimum\":true,\""
    "type\":\"number\",\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\"},\"origin\":{\"$ref\":\"#/defi"
    "nitions/vector\",\"description\":\"Sensor origin in SOCS [m] at frame "
    "angle = 0\"}},\"type\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_a"
    "xis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Acceler"
    "ometer details\"},\"gyroscope\":{\"properties\":{\"relative_nonlinearity\":{\""
    "$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, dim"
    "ensionless\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Va"
    "lue to be subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#"
    "/definitions/vector\",\"description\":\"Sensitive X axis of sensor at "
    "frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"exclusiveMinimum\":true,\""
    "type\":\"number\",\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in "
    "rad/s\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\"}},\"type\":\"object\",\"required\":[\""
    "unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinear"
    "ity\"],\"description\":\"Gyroscope details\"},\"magnetic_field_sensor\":{\"pro"
    "perties\":{\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"desc"
    "ription\":\"Relative nonlinearity, dimensionless\"},\"fixed\":{\"$ref\":\"#/de"
    "finitions/vector\",\"description\":\"Distortion of magnetic field caused "
    "by non-rotating scanner "
    "part\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to"
    " be subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#/defin"
    "itions/vector\",\"description\":\"Sensitive X axis of sensor at frame "
    "angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"exclusiveMinimum\":true,\""
    "type\":\"number\",\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in nT\"}},\"type\":\"object\",\"required\":[\"unit\","
    "\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\""
    "description\":\"Magnetic Field Sensor details\"}},\"type\":\"object\",\"defini"
    "tions\":{\"vector\":{\"minItems\":3,\"type\":\"array\",\"items\":{\"type\":\"number\""
    ",\"description\":\"Index 0=X, 1=Y, 2=Z "
    "component\"},\"maxItems\":3}},\"description\":\"Details on position and "
    "orientation sensors\"}"
    ,
    /* example: */
    "{\"accelerometer\":{\"relative_nonlinearity\":[0.0,0.0,0.0],\"offset\":[-733"
    ".3636474609375,58.969032287597656,1060.2550048828125],\"x_axis\":[-15008"
    ".123046875,56.956390380859375,-60.5175666809082],\"z_axis\":[1.639882206"
    "916809,15166.744140625,-116.99742889404297],\"y_axis\":[-7.0272889137268"
    "07,-44.12333679199219,14952.3701171875],\"unit\":6.666666740784422e-05,\""
    "origin\":[0.026900000870227814,-0.03999999910593033,-0.0895000025629997"
    "3]},\"gyroscope\":{\"relative_nonlinearity\":[2.888176311444113e-07,1.0627"
    "4164579645e-07,-1.7186295080634935e-39],\"offset\":[-50.92609786987305,1"
    "46.15643310546875,62.4327278137207],\"x_axis\":[-121.195556640625,0.8219"
    "714164733887,0.2313031703233719],\"z_axis\":[0.555869996547699,119.22135"
    "162353516,0.467585027217865],\"y_axis\":[-0.440765917301178,-0.789739966"
    "3925171,119.5894775390625],\"unit\":0.00014544410805683583,\"origin\":[0.0"
    "26900000870227814,-0.03999999910593033,-0.08950000256299973]},\"magneti"
    "c_field_sensor\":{\"relative_nonlinearity\":[0.0,0.0,0.0],\"fixed\":[-1576."
    "010498046875,1596.081787109375,0.0],\"offset\":[-23812.052734375,5606.57"
    "666015625,2493.28125],\"x_axis\":[-0.011162743903696537,-2.3159627744462"
    "34e-05,0.00016818844596855342],\"z_axis\":[0.00041987866279669106,7.8769"
    "77906562388e-05,0.011407104320824146],\"y_axis\":[0.00027888521435670555"
    ",-0.011427424848079681,-5.204829722060822e-05],\"unit\":91.7431182861328"
    "1}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Pulse Position Modulation\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval"
    "\"],\"properties\":{\"pulse_interval\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\",\"minimum\":0},\"description\":\"Explicit table of the pulse position "
    "modulation used for MTA resolution. Table gives times between "
    "successive laser pulses in seconds.\"},\"length\":{\"type\":\"integer\",\"maxi"
    "mum\":255,\"minimum\":0,\"description\":\"Length of code\"},\"phase_step\":{\"ty"
    "pe\":\"integer\",\"maximum\":255,\"minimum\":0,\"description\":\"Step width in "
    "phase of modulation code from line to line\"},\"code_phase_mode\":{\"type\""
    ":\"integer\",\"maximum\":255,\"minimum\":0,\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\"},\"num_mod_ampl\":{\"type\":\"integer\",\"maximum\":255,\"minimum\":0,"
    "\"description\":\"Number of different modulation amplitudes (2: binary "
    "modulation)\"}},\"description\":\"Laser pulse position modulation used for"
    " MTA resolution\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"length\":31,\"phase_step\":5,\"code_phase_mode\":2,\"num_mod_ampl\":2}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Range Statistics\",\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"proper"
    "ties\":{\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"}},\"description\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"std_dev\":24.349,\"maximum\":574.35,\"average\":15.49738,\"minimum\":0.919}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Receiver Internals\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"properties\":{\"t\":{\"type\":\"object\",\"additionalProperties\":"
    "false,\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/fp\",\"desc"
    "ription\":\"one field per channel, field name is channel "
    "index\"}}},\"si\":{\"type\":\"number\",\"description\":\"Start index (hw_start)\""
    ",\"minimum\":0,\"maximum\":255},\"ns\":{\"type\":\"integer\",\"description\":\"Numb"
    "er of samples\",\"minimum\":0,\"maximum\":4095},\"a\":{\"minItems\":1,\"type\":\"a"
    "rray\",\"items\":{\"type\":\"number\"},\"description\":\"Amplitude [dB]\",\"maxIte"
    "ms\":256},\"mw\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"description\":\""
    "Maximum weight\",\"minimum\":0,\"maximum\":4095},\"sr\":{\"exclusiveMinimum\":t"
    "rue,\"type\":\"number\",\"minimum\":0,\"description\":\"Sample rate [Hz]\"},\"tbl"
    "\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"$ref\":\"#/definitions/fp_table"
    "\"},\"description\":\"various internal "
    "data\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\"},\"nt\":{\"type\":\"integer\",\"description\":\"Number of traces\",\"min"
    "imum\":0,\"maximum\":255}},\"type\":\"object\",\"definitions\":{\"fp_table\":{\"pr"
    "operties\":{\"tc\":{\"type\":\"integer\",\"description\":\"table data type "
    "code\",\"min\":0,\"max\":255},\"ch\":{\"type\":\"integer\",\"description\":\"channel"
    " number\",\"min\":0,\"max\":255},\"tv\":{\"minItems\":1,\"type\":\"array\",\"items\":"
    "{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]},\"m"
    "axItems\":2048},\"nx\":{\"type\":\"integer\",\"description\":\"number of x entri"
    "es\",\"min\":1,\"max\":2048},\"ny\":{\"type\":\"integer\",\"description\":\"number "
    "of y entries\",\"min\":1,\"max\":2048}},\"type\":\"object\",\"required\":[\"ch\",\"t"
    "c\",\"nx\",\"ny\",\"tv\"],\"desription\":\"scanner internal data\"},\"fp_table_row"
    "\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems\":20"
    "48},\"fp\":{\"properties\":{\"s\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"min"
    "Items\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems\":4096},\"ma"
    "xItems\":256},\"w\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"minItems\":5,\"t"
    "ype\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems\":5},\"maxItems\":256}},"
    "\"type\":\"object\",\"required\":[\"s\",\"w\"],\"description\":\"Fingerprint "
    "values\"}},\"description\":\"Receiver Internals\"}"
    ,
    /* example: */
    "{\"t\":{\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,8"
    "6,126,134,31]]},\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134"
    ",31],[78,86,126,134,31]]}},\"si\":48,\"ns\":400,\"a\":[-1.55],\"mw\":31,\"sr\":7"
    "959997000.0,\"tbl\":[{\"tc\":1,\"ch\":0,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5"
    ".5]],\"nx\":5,\"ny\":2}],\"nt\":128}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Reflectance Calculation Table\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"required\":[\"delta\",\"content\"],\"properties\":{\"c"
    "ontent\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxIte"
    "ms\":2000,\"description\":\"Correction value [dB] to be added to the "
    "amplitude\"},\"delta\":{\"type\":\"number\",\"description\":\"Delta between "
    "table entries [m], first entry is at range = 0 "
    "m\"}},\"description\":\"Lookup table for reflectance calculation based on "
    "amplitude and range\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"content\":[-33.01],\"delta\":0.150918}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Near-range reflectance correction\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"required\":[\"ranges_m\",\"line_angles_deg\",\"r"
    "eflectance_correction_db\"],\"properties\":{\"line_angles_deg\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\"},\"description\":\"Angle [deg]\"},\"ranges_m\""
    ":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Range [m]\"},"
    "\"reflectance_correction_db\":{\"type\":\"array\",\"items\":{\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\",\"description\":\"columns (each value corresponds "
    "to an angle)\"},\"description\":\"rows (each array corresponds to a "
    "range)\"},\"description\":\"Near range reflectance correction in dB as a "
    "function of range over angle\"}},\"description\":\"Range-dependent and "
    "scan-angle-dependent correction of reflectance "
    "reading\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m"
    "\":[0.0,1.0,2.0,3.0],\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,"
    "0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0."
    "8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,"
    "0.1,0.05,0.01]]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Scan Pattern\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"definitions\":{\"program\":{\"properties\":{\"laser_prr\":{\"exclusiveM"
    "inimum\":false,\"type\":\"number\",\"minimum\":0,\"description\":\"Laser Pulse "
    "Repetition Rate [Hz]\"},\"name\":{\"type\":\"string\",\"description\":\"Name of "
    "measurement program\"}},\"type\":\"object\",\"required\":[\"name\"],\"descriptio"
    "n\":\"Measurement program\"}},\"properties\":{\"segments\":{\"properties\":{\"li"
    "st\":{\"type\":\"array\",\"items\":{\"properties\":{\"stop\":{\"type\":\"number\",\"ma"
    "ximum\":720.0,\"minimum\":0.0,\"description\":\"Stop angle in SOCS [deg]\"},\""
    "start\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":0.0,\"description\":\"S"
    "tart angle in SOCS [deg]\"},\"increment\":{\"type\":\"number\",\"maximum\":90.0"
    ",\"minimum\":0.0,\"description\":\"Increment of angle in SOCS [deg]\"}},\"typ"
    "e\":\"object\",\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Lin"
    "e Scan Segment\"}},\"program\":{\"$ref\":\"#/definitions/program\"}},\"type\":\""
    "object\",\"required\":[\"list\"],\"description\":\"Segmented Line Scan Pattern"
    "\"},\"line\":{\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"s"
    "top\":{\"type\":\"number\",\"maximum\":720.0,\"minimum\":0.0,\"description\":\"Sto"
    "p angle in SOCS [deg]\"},\"start\":{\"type\":\"number\",\"maximum\":360.0,\"mini"
    "mum\":0.0,\"description\":\"Start angle in SOCS [deg]\"},\"increment\":{\"type"
    "\":\"number\",\"maximum\":90.0,\"minimum\":0.0,\"description\":\"Increment of "
    "angle in SOCS [deg]\"}},\"type\":\"object\",\"required\":[\"start\",\"stop\",\"inc"
    "rement\"],\"description\":\"Line Scan Pattern\"},\"rectangular\":{\"properties"
    "\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"theta_start\":{\"type\":\"n"
    "umber\",\"maximum\":180.0,\"minimum\":0.0,\"description\":\"Start theta angle "
    "in SOCS [deg]\"},\"phi_increment\":{\"type\":\"number\",\"maximum\":90.0,\"minim"
    "um\":0.0,\"description\":\"Increment of phi angle in SOCS [deg]\"},\"theta_i"
    "ncrement\":{\"type\":\"number\",\"maximum\":90.0,\"minimum\":0.0,\"description\":"
    "\"Increment of theta angle in SOCS [deg]\"},\"phi_stop\":{\"type\":\"number\","
    "\"maximum\":720.0,\"minimum\":0.0,\"description\":\"Stop phi angle in SOCS [d"
    "eg]\"},\"theta_stop\":{\"type\":\"number\",\"maximum\":180.0,\"minimum\":0.0,\"des"
    "cription\":\"Stop theta angle in SOCS [deg]\"},\"phi_start\":{\"type\":\"numbe"
    "r\",\"maximum\":360.0,\"minimum\":0.0,\"description\":\"Start phi angle in "
    "SOCS [deg]\"}},\"type\":\"object\",\"required\":[\"phi_start\",\"phi_stop\",\"phi_"
    "increment\",\"theta_start\",\"theta_stop\",\"theta_increment\"],\"description\""
    ":\"Rectangular Field Of View Scan Pattern\"}},\"description\":\"Scan "
    "pattern description\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"program\":{\"laser_prr\":100000.0,\"name\":\"High Speed\"},\""
    "theta_start\":30.0,\"phi_increment\":0.04,\"theta_increment\":0.04,\"phi_sto"
    "p\":270.0,\"theta_stop\":130.0,\"phi_start\":45.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Shot Information\",\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"properties\":{\"shot_file\":{\"properties\":{\"file_extension\":{\""
    "type\":\"string\",\"description\":\"Shot file extension, without the leading"
    " dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\":[\"file_exte"
    "nsion\"]}},\"type\":\"object\",\"description\":\"Details about laser shot "
    "files\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_extension\":\"sodx\",\"file_uuid\":\"26a00815-67c0-4bff-"
    "8fe8-c577378fe663\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Stored filters\",\"$schema\":\"http://json-schema.org/draft-04/s"
    "chema#\",\"required\":[\"activated\",\"filters\"],\"properties\":{\"filters\":{\"t"
    "ype\":\"array\",\"items\":{\"properties\":{\"title\":{\"type\":\"string\",\"descript"
    "ion\":\"A short filter title (e.g. for display in a selection "
    "list)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter string"
    " to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a tooltip)\"}},\"type\":\"o"
    "bject\",\"required\":[\"activated\",\"title\",\"description\",\"filter\"],\"descri"
    "ption\":\"Point filter definition\"},\"description\":\"List of point "
    "filters\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') "
    "or ignore ('false') all filters\"}},\"description\":\"Point filters "
    "applied in addition to the application-defined "
    "filters\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"filters\":[{\"title\":\"Ignore uncertain points from MTA "
    "resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with uncertain MTA "
    "zone assignment\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with an echo signal "
    "amplitude below the dynamic trigger\"},{\"title\":\"Ignore points outside "
    "outer AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are outside the"
    " outer AABB in BOCS\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are inside the "
    "inner AABB in BOCS\"}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"System Description\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"syste"
    "m\"],\"properties\":{\"timestamp\":{\"type\":\"string\",\"description\":\"Date and"
    " time of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"system\":{\"type\":"
    "\"object\",\"description\":\"The actual system description, details see "
    "documentation of RIEGL System "
    "Description\"},\"version\":{\"type\":\"string\",\"description\":\"Document "
    "format version\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the document\"},\"$class\":{\"type\":\"string\",\"enum\":[\""
    "Document\"],\"description\":\"Object class name\"}},\"description\":\"Details "
    "of major system components like lidar sensors, cameras and navigation "
    "devices\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"system\":{\"details\":\"see "
    "documentation of RIEGL System "
    "Description\"},\"version\":\"1.2.1\",\"author\":\"RIEGL LMS GmbH, "
    "Austria\",\"$class\":\"Document\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Temperature Calculation Table\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"properties\":{\"InGaAs_Si_Difference\":{\"$ref\":\"#"
    "/definitions/conversion_table\",\"description\":\"Conversion table for "
    "InGaAs - Si difference\"},\"InGaAs\":{\"$ref\":\"#/definitions/conversion_ta"
    "ble\",\"description\":\"Conversion table for InGaAs channel\"},\"Si\":{\"$ref\""
    ":\"#/definitions/conversion_table\",\"description\":\"Conversion table for "
    "Si channel\"}},\"type\":\"object\",\"definitions\":{\"conversion_table\":{\"prop"
    "erties\":{\"temperature\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"desc"
    "ription\":\"Temperature [\\u00b0C]\"},\"value\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"LSB [1]\"}},\"type\":\"object\",\"required\":[\"v"
    "alue\",\"temperature\"]}},\"description\":\"Conversion of background "
    "radiation raw values to temperatures in \\u00b0C\"}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"temperature\":[1749.977111117893,1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1744.7813348796044,1681.9971312601092,1622.3944822534868],\"val"
    "ue\":[1000.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400"
    ".0885036774805,1500.0427259132668,1600.1327555162209,1700.086977752006"
    "5,1800.0411999877924]},\"InGaAs\":{\"temperature\":[307.22196722535614,309"
    ".1153478247277,311.1188086915047,313.10025350480055,315.2137946389828,"
    "317.2172555057597,319.2207163725366,321.2021611858325,323.315702320014"
    "8],\"value\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,"
    "256.0039063692129,320.00488296151616,384.0058595538194,448.00683614612"
    "26,512.0078127384259]},\"Si\":{\"temperature\":[546.300048828125,548.81640"
    "51212026,551.3143938500972,554.0144257850053,556.604252334815,559.2124"
    "464488079,561.8022729986177,564.4104671126105,567.0002936624203],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Time Base\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"required\":[\"epoch\",\"source\"],\"properties\":{\"system\":{\"type\":\"strin"
    "g\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"],\"description\":\"Time system (time "
    "standard)\"},\"epoch\":{\"type\":\"string\",\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\"},\"source\":{\"type\":\"string\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"descrip"
    "tion\":\"Timestamp source\"}},\"description\":\"Base of timestamps "
    "(epoch)\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Trajectory Information\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"time_interval\",\"navigation_frame\"],\"prope"
    "rties\":{\"field_of_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS"
    "\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field of a"
    "pplication\"},\"time_interval\":{\"properties\":{\"std_dev\":{\"type\":\"number\""
    ",\"description\":\"Standard deviation of intervals "
    "[s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"}},\"type\":\"object\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_"
    "dev\"],\"description\":\"Time interval "
    "statistics\"},\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"},\"device\":{\"type\":\"string\",\"descrip"
    "tion\":\"Navigation device, e.g. "
    "name/type/serial\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings"
    " used to calculate the trajectory (descriptive "
    "text)\"},\"project\":{\"type\":\"string\",\"description\":\"Project name\"},\"navi"
    "gation_frame\":{\"type\":\"string\",\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"descrip"
    "tion\":\"Navigation frame (NED: North-East-Down, ENU: "
    "East-North-Up)\"},\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the file)\"}},\"description\":\"Details about "
    "position+orientation files\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"MLS\",\"time_interval\":{\"std_dev\":5.51e-07,\"max"
    "imum\":0.005004883,\"average\":0.00500053,\"minimum\":0.00500032},\"location"
    "\":\"Horn\",\"device\":\"IMU Model 12/1, Serial# "
    "12345\",\"settings\":\"default\",\"project\":\"Campaign "
    "3\",\"navigation_frame\":\"NED\",\"company\":\"RIEGL "
    "LMS\",\"software\":\"Navigation Software XYZ\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"TTIP Configuration\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ex"
    "t_signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_m"
    "in_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\""
    "input_descr\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration"
    "\",\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_du"
    "ration\",\"in_max_duration\",\"in_max_delay\"],\"properties\":{\"output_usage\""
    ":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .. no output, 1 .. "
    "output derived from internal clock, 2 .. output derived from dmi, 3 .."
    " output derived from external signal, 4 .. output static low, 5 .. "
    "output static "
    "high\"},\"input_usage\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .."
    " deactivated, 1 .. just detecting and timestamping\"},\"output_descr\":{\""
    "type\":\"string\",\"description\":\"descriptive string\"},\"in_min_duration\":{"
    "\"type\":\"integer\",\"minimum\":0,\"description\":\"input signals with smaller"
    " pulse durations are ignored [0.1 msec]\"},\"out_interval\":{\"type\":\"inte"
    "ger\",\"minimum\":0,\"description\":\"output pulse interval [0.1 msec]\"},\"dm"
    "i_min_time\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"dmi, minimum "
    "time interval between trigger events [0.1 msec]\"},\"in_max_delay\":{\"typ"
    "e\":\"integer\",\"minimum\":0,\"description\":\"maximum delay to output pulse "
    "before fake event is generated [0.1 msec], zero indicates that no fake"
    " events are generated\"},\"num_channel\":{\"type\":\"integer\",\"minimum\":0,\"d"
    "escription\":\"number of input/output channels\"},\"dmi_max_time\":{\"type\":"
    "\"integer\",\"minimum\":0,\"description\":\"dmi, maximum time interval "
    "between trigger events [0.1 msec]\"},\"out_duration\":{\"type\":\"integer\",\""
    "minimum\":0,\"description\":\"output pulse duration [0.1 "
    "msec]\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\"},\"out_polarity\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .."
    " positive edge, 1 .. negative edge\"},\"out_num_pulses\":{\"type\":\"integer"
    "\",\"minimum\":0,\"description\":\"number of output pulses to be generated, "
    "0 .. "
    "infinite\"},\"ext_signal\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0"
    " .. use input signal, 1 .. use output signal of channel\"},\"ttip_versio"
    "n\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"following main.sub.ss."
    "sss\"},\"ext_subdivider\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"re"
    "duces the frequency, default 1\"},\"in_max_duration\":{\"type\":\"integer\",\""
    "minimum\":0,\"description\":\"stops measurement of pulse duration of input"
    " signal [0.1 msec]\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, "
    "increment in ticks\"},\"ext_delay\":{\"type\":\"integer\",\"minimum\":0,\"descri"
    "ption\":\"external trigger, time delay [0.1 msec]\"},\"ext_bitmask\":{\"type"
    "\":\"integer\",\"minimum\":0,\"description\":\"defines which of the internal "
    "pulse generators are to be "
    "started\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"in_polarity\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\"},\"out_delay\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"output"
    " pulse initial delay after start [0.1 "
    "msec]\"},\"ext_channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID of "
    "input/output channel\"}},\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"output_usage\":1,\"input_usage\":1,\"output_descr\":\"Port 1 - Trigger\",\"i"
    "n_min_duration\":0,\"out_interval\":10000,\"dmi_min_time\":0,\"in_max_delay\""
    ":9990,\"num_channel\":9,\"dmi_max_time\":0,\"out_duration\":300,\"dmi_dist_pe"
    "r_tick\":0.0,\"out_polarity\":0,\"out_num_pulses\":1,\"ext_signal\":0,\"ttip_v"
    "ersion\":1,\"ext_subdivider\":1,\"in_max_duration\":10000,\"dmi_incr\":0,\"ext"
    "_delay\":0,\"ext_bitmask\":0,\"input_descr\":\"Port 1 - "
    "Exposure\",\"in_polarity\":0,\"out_delay\":0,\"ext_channel\":32,\"channel\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Vertex Information\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"properties\":{\"vertex_file\":{\"properties\":{\"file_extension"
    "\":{\"type\":\"string\",\"description\":\"Vertex file extension, without the "
    "leading dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\""
    ":[\"file_extension\"]}},\"type\":\"object\",\"description\":\"Details about "
    "vertex file\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_extension\":\"vtx\",\"file_uuid\":\"51534d95-d71f-4f36"
    "-ae1a-3e63a21fd1c7\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Voxel Information\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"definitions\":{\"voxel_origin_enum\":{\"default\":\"corner\",\"enu"
    "m\":[\"center\",\"corner\"],\"description\":\"Defines whether the voxel's "
    "center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\"},\"voxel_"
    "size\":{\"minItems\":3,\"type\":\"array\",\"items\":{\"$ref\":\"#/definitions/edge"
    "_length\"},\"maxItems\":3,\"description\":\"Size of voxels.\"},\"shape_thresho"
    "lds\":{\"properties\":{\"plane\":{\"exclusiveMaximum\":true,\"minimum\":0,\"type"
    "\":\"number\",\"exclusiveMinimum\":true,\"maximum\":1,\"description\":\"If the "
    "smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\"},\"line\":{\"exclusive"
    "Minimum\":true,\"type\":\"number\",\"minimum\":1,\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\"}},\"type\":\"object\",\"re"
    "quired\":[\"plane\",\"line\"],\"description\":\"Thresholds used to compute the"
    " voxel's shape_id value.\"},\"voxel_size_cubic\":{\"$ref\":\"#/definitions/e"
    "dge_length\",\"type\":\"number\"},\"edge_length\":{\"exclusiveMinimum\":true,\"t"
    "ype\":\"number\",\"minimum\":0,\"description\":\"Length of voxel edge [m].\"},\""
    "voxel_origin_point\":{\"minItems\":3,\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"maxItems\":3,\"description\":\"Origin point for all voxel indices in"
    " voxel CRS.\"},\"voxel_type\":{\"default\":\"centroid\",\"enum\":[\"center\",\"cen"
    "troid\",\"index\"],\"description\":\"Whether a point in a voxel represents "
    "its center or its centroid. If type is <tt>index</tt> there is no "
    "point but only an integer voxel index.\"}},\"description\":\"Details about"
    " the voxels contained in the file\",\"type\":\"object\",\"oneOf\":[{\"properti"
    "es\":{\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"},\"shape_"
    "thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"size\":{\"oneOf\":"
    "[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size"
    "_cubic\"}],\"description\":\"Size of voxels in file coordinate system.\"},\""
    "voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"}},\"required\":[\"size\",\"v"
    "oxel_origin\",\"voxel_type\"],\"additionalProperties\":false},{\"properties\""
    ":{\"reference_point\":{\"minItems\":2,\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\",\"minimum\":-180,\"maximum\":180},\"maxItems\":2,\"description\":\"Point in"
    " WGS84 geodetic decimal degree (EPSG:4326) that was used to compute "
    "the projection distortion parameters. The coefficient order is "
    "latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\"},\"voxe"
    "l_origin\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_origin_enum\"},{\"$ref\""
    ":\"#/definitions/voxel_origin_point\",\"description\":\"The base point of "
    "the voxel grid. Used together with <tt>voxel_size</tt> and "
    "<tt>voxel_index</tt> to compute actual point coordinates.\"}]},\"shape_t"
    "hresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_type\":{\"$r"
    "ef\":\"#/definitions/voxel_type\"},\"size\":{\"$ref\":\"#/definitions/voxel_si"
    "ze\",\"description\":\"Size of voxels in file coordinate system.\"},\"size_l"
    "lcs\":{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size of voxels "
    "in a locally levelled cartesian coordinate system (xyz). This is only "
    "used for voxels based on a map projection.\"}},\"required\":[\"reference_p"
    "oint\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"],\"additionalPrope"
    "rties\":false}]}"
    ,
    /* example: */
    "{\"reference_point\":[48,16],\"voxel_origin\":\"corner\",\"shape_thresholds\":"
    "{\"plane\":0.16,\"line\":6},\"voxel_type\":\"centroid\",\"size\":[0.597164283477"
    "9395,0.5971642834779395,0.5143705304787237],\"size_llcs\":[0.51565752528"
    "91171,0.5130835356683303,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Waveform Averaging Settings\",\"$schema\":\"http://json-schema.o"
    "rg/draft-04/schema#\",\"required\":[\"num_shots\",\"mta_zone\"],\"properties\":"
    "{\"trim\":{\"type\":\"number\",\"maximum\":0.5,\"default\":0,\"minimum\":0,\"descri"
    "ption\":\"Percentage for robust averaging.\"},\"mta_zone\":{\"type\":\"integer"
    "\",\"minimum\":1,\"description\":\"Fixed MTA zone for averaging.\"},\"num_shot"
    "s\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of consecutive "
    "shots to be used for averaging.\"}},\"description\":\"Settings for "
    "waveform averaging\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"trim\":0.05,\"mta_zone\":1,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Waveform Information\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"required\":[\"sample_block_file\",\"sample_data_files\"],\"pr"
    "operties\":{\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated"
    " device specific range offset for waveform analysis by system response"
    " fitting in meters.\"},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"pr"
    "operties\":{\"laser_wavelength\":{\"exclusiveMinimum\":false,\"type\":\"number"
    "\",\"minimum\":0,\"description\":\"Laser wavelength in meters (0 = unknown)\""
    "},\"sample_interval\":{\"exclusiveMinimum\":false,\"type\":\"number\",\"minimum"
    "\":0,\"description\":\"Sampling interval in seconds\"},\"sample_bits\":{\"excl"
    "usiveMaximum\":false,\"maximum\":32,\"minimum\":0,\"description\":\"Bitwidth "
    "of samples (e.g. 10 bit, 12 bit)\",\"exclusiveMinimum\":false,\"type\":\"int"
    "eger\"},\"delta_st\":{\"type\":\"number\",\"description\":\"reserved\"},\"file_ext"
    "ension\":{\"type\":\"string\",\"description\":\"Sample data file extension, "
    "without the leading dot\"},\"channel\":{\"exclusiveMaximum\":false,\"maximum"
    "\":255,\"minimum\":0,\"description\":\"Sample block channel number (255 = in"
    "valid)\",\"exclusiveMinimum\":false,\"type\":\"integer\"},\"file_uuid\":{\"type\""
    ":\"string\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"}},\"type\":\"object\",\"required\":[\"channel\",\"channel_name\",\""
    "sample_interval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_ext"
    "ension\"]}},\"range_offset_waveform_samples_m\":{\"type\":\"number\",\"descrip"
    "tion\":\"Calibrated device specific range offset for waveform samples in"
    " meters.\"},\"sample_block_file\":{\"properties\":{\"file_extension\":{\"type\""
    ":\"string\",\"description\":\"Sample block file extension, without the "
    "leading dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"}},\"type\":\"object\",\"required\""
    ":[\"file_extension\"]}},\"description\":\"Details about waveform "
    "files\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"range_offset_m\":3.1415,\"range_offset_waveform_samples_m \":7.283,\"sam"
    "ple_data_files\":[{\"laser_wavelength\":0,\"sample_interval\":1.00503e-09,\""
    "sample_bits\":12,\"delta_st\":0,\"file_extension\":\"sp0\",\"channel_name\":\"hi"
    "gh_power\",\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"channel\""
    ":0},{\"laser_wavelength\":0,\"sample_interval\":1.00503e-09,\"sample_bits\":"
    "12,\"delta_st\":0,\"file_extension\":\"sp1\",\"channel_name\":\"low_power\",\"fil"
    "e_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"channel\":1},{\"laser_wa"
    "velength\":0,\"sample_interval\":1.00503e-09,\"sample_bits\":12,\"delta_st\":"
    "0,\"file_extension\":\"sp5\",\"channel_name\":\"wwf\",\"file_uuid\":\"9d2298c4-10"
    "36-464f-b5cb-1cf8e517f3a0\",\"channel\":5}],\"sample_block_file\":{\"file_ex"
    "tension\":\"sbx\",\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\"}}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Waveform Settings\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"items\":{\"properties\":{\"pass_rng_less\":{\"type\":\"number\",\"de"
    "scription\":\"Threshold for range less than "
    "[m]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform"
    " output enabled\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform "
    "output enabled\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of "
    "sample block, e.g.: wfm, "
    "wwf\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, "
    "...\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation greater than [1]\"}},\"type\":\"object\",\"required\":[\"sbl_na"
    "me\",\"enabled\",\"channel_idx_mask\"]},\"type\":\"array\",\"description\":\"Scann"
    "er settings for waveform output\"}"
    ,
    /* example: */
    "[{\"pass_rng_less\":13.11,\"pass_rng_greater\":9.27,\"pass_ampl_less\":5.0,\""
    "smart_enabled\":true,\"enabled\":true,\"sbl_name\":\"wfm\",\"channel_idx_mask\""
    ":11,\"pass_ampl_greater\":1.0},{\"sbl_name\":\"wwf\",\"channel_idx_mask\":32,\""
    "enabled\":false}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Window Analysis\",\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"required\":[\"result\",\"filter\",\"settings\"],\"properties\":{\"resu"
    "lt\":{\"properties\":{\"amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"n"
    "umber\"},\"description\":\"[dB]\"},\"amplitude_sigma\":{\"type\":\"array\",\"items"
    "\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"angle\":{\"type\":\"array\",\"ite"
    "ms\":{\"type\":\"number\"},\"description\":\"[deg]\"},\"range_mean\":{\"type\":\"arr"
    "ay\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"timestamp\":{\"type\""
    ":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[s]\"},\"amplitude_off"
    "set\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\""
    "range_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\""
    "[m]\"}},\"type\":\"object\",\"required\":[\"angle\",\"range_mean\",\"range_sigma\","
    "\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offset\"]},\"filter\":{\"pro"
    "perties\":{\"range_min\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"[m]\"},\"angle\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"desc"
    "ription\":\"[deg]\"},\"amplitude_max\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"},\"description\":\"[dB]\"},\"range_max\":{\"type\":\"array\",\"items\":{\"type"
    "\":\"number\"},\"description\":\"[m]\"}},\"type\":\"object\",\"required\":[\"angle\","
    "\"range_min\",\"range_max\",\"amplitude_max\"]},\"settings\":{\"properties\":{\"r"
    "ange\":{\"properties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_factor\""
    ":{\"type\":\"number\"}},\"type\":\"object\",\"required\":[\"sigma_factor\",\"additi"
    "ve_value\"]},\"amplitude\":{\"properties\":{\"additive_value\":{\"type\":\"numbe"
    "r\"},\"sigma_factor\":{\"type\":\"number\"}},\"type\":\"object\",\"required\":[\"sig"
    "ma_factor\",\"additive_value\"]}},\"type\":\"object\",\"required\":[\"range\",\"am"
    "plitude\"]}},\"description\":\"Window analysis data estimated from "
    "scandata and resulting filter parameters\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"result\":{\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097"
    "782,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],\"amplitude_sig"
    "ma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.437"
    "3984,0.4472798,0.4346001,0.4345487,0.4540681],\"angle\":[14.9,15.0,15.1,"
    "15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"range_mean\":[0.1105621,0.107"
    "9564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051"
    "523,0.1058445,0.1031261],\"timestamp\":[408.4441,411.4443],\"amplitude_of"
    "fset\":[1.9,1.9],\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.0191"
    "8765,0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122"
    ",0.02009433]},\"filter\":{\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216"
    ",-0.218,-0.219,-0.221,-0.223,-0.225,-0.227],\"angle\":[14.9,15.0,15.1,15"
    ".2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"amplitude_max\":[8.04,8.01,7.99"
    ",7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],\"range_max\":[0.424,0.425,0.426"
    ",0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432]},\"settings\":{\"range\":"
    "{\"additive_value\":0.1,\"sigma_factor\":8},\"amplitude\":{\"additive_value\":"
    "1.0,\"sigma_factor\":4}}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Window Echo Correction\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"amplitude\",\"range\",\"slices\"],\"properties\""
    ":{\"slices\":{\"type\":\"array\",\"items\":{\"properties\":{\"amplitude\":{\"type\":"
    "\"number\",\"description\":\"Window echo amplitude of slice in dB\"},\"table\""
    ":{\"minItems\":1,\"type\":\"array\",\"items\":{\"minItems\":1,\"type\":\"array\",\"it"
    "ems\":{\"minItems\":3,\"type\":\"array\",\"items\":{\"type\":\"number\",\"descriptio"
    "n\":\"Table cell (item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\"},\"maxItems\":3,\"description\":\"Table column (= range "
    "axis)\"},\"description\":\"Table row (= amplitude "
    "axis)\"},\"description\":\"Correction table (dimension defined by the "
    "'amplitude' and 'range' objects)\"}},\"type\":\"object\",\"required\":[\"ampli"
    "tude\",\"table\"],\"description\":\"Window echo correction parameter slice\"}"
    "},\"range\":{\"properties\":{\"maximum\":{\"type\":\"number\",\"maximum\":2.0,\"min"
    "imum\":-2.0,\"description\":\"Maximum range in m\"},\"minimum\":{\"type\":\"numb"
    "er\",\"maximum\":2.0,\"minimum\":-2.0,\"description\":\"Minimum range in "
    "m\"},\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "range entries\"}},\"type\":\"object\",\"required\":[\"minimum\",\"maximum\",\"entr"
    "ies\"],\"description\":\"Range axis of correction table\"},\"amplitude\":{\"pr"
    "operties\":{\"maximum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Max"
    "imum amplitude in "
    "dB\"},\"minimum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Minimum "
    "amplitude in "
    "dB\"},\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "amplitude entries\"}},\"type\":\"object\",\"required\":[\"minimum\",\"maximum\",\""
    "entries\"],\"description\":\"Amplitude axis of correction "
    "table\"}},\"description\":\"Correction parameters for window glass "
    "echoes\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"slices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,"
    "1]]]},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}"
    "],\"range\":{\"maximum\":1.5060822940732335,\"minimum\":-1.5060822940732335,"
    "\"entries\":128},\"amplitude\":{\"maximum\":20,\"minimum\":2,\"entries\":128}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
